#[non_exhaustive]pub enum LinDist3FlowStandardRowOrigin {
Equality(LinDist3FlowEqualityOrigin),
VariableLowerBound {
column: usize,
},
VariableUpperBound {
column: usize,
},
Cone {
origin: LinDist3FlowConeOrigin,
row_in_cone: usize,
},
}Expand description
Semantic provenance for one row of A and b.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Equality(LinDist3FlowEqualityOrigin)
VariableLowerBound
VariableUpperBound
Cone
Fields

origin: LinDist3FlowConeOriginTrait Implementations
Sourceimpl Clone for LinDist3FlowStandardRowOrigin
impl Clone for LinDist3FlowStandardRowOrigin
Sourcefn clone(&self) -> LinDist3FlowStandardRowOrigin
fn clone(&self) -> LinDist3FlowStandardRowOrigin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for LinDist3FlowStandardRowOrigin
Sourceimpl PartialEq for LinDist3FlowStandardRowOrigin
impl PartialEq for LinDist3FlowStandardRowOrigin
Sourcefn eq(&self, other: &LinDist3FlowStandardRowOrigin) -> bool
fn eq(&self, other: &LinDist3FlowStandardRowOrigin) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LinDist3FlowStandardRowOrigin