PreparedAcBusSpecification

Enum PreparedAcBusSpecification 

#[non_exhaustive]
pub enum PreparedAcBusSpecification { Pq { p: f64, q: f64, }, Pv { p: f64, vm: f64, }, Reference { vm: f64, va: f64, }, Isolated, }
One AC power flow bus specification in preparation units.

This has the same cases as AcBusSpecification, but active and reactive power use the preparation’s selected Units and reference angles are radians. The builder converts the caller’s exact case and values; it never derives a replacement from the network bus type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Pq

Fields



Pv

Fields

vm: f64


Reference

Fields

vm: f64
va: f64


Isolated