line_drop_coefficients

Function line_drop_coefficients 

pub fn line_drop_coefficients(
    impedance: &[Vec<Complex64>],
    reference_from: &[Complex64],
) -> Result<LineDropCoefficients>
Construct the line voltage-drop blocks for a complex series impedance.

Gamma[phi, psi] = vbar_phi / vbar_psi, M = 2 Re(conj(Z) .* Gamma), and N = -2 Im(conj(Z) .* Gamma).

Errors

Z is not finite and square with the reference arity, or a reference phasor is zero or non-finite.