winding_voltage_coefficients

Function winding_voltage_coefficients 

pub fn winding_voltage_coefficients(
    incidence: &[f64],
    reference: &[Complex64],
) -> Result<AffineScalarCoefficients>
Form real affine coefficients for the squared winding voltage |d v|^2.

Errors

The incidence row and reference have different or zero length, contain a non-finite value, or a reference phasor is zero.