#[non_exhaustive]pub struct AcPfPreparation {Show 16 fields
pub name: String,
pub n_buses: usize,
pub n_source_generators: usize,
pub n_source_branches: usize,
pub base_mva: f64,
pub units: Units,
pub skip_zero_impedance: bool,
pub correct_angle_difference_bounds: bool,
pub bus_ids: Vec<BusId>,
pub bus_analysis_rows: Vec<usize>,
pub bus_source_rows: Vec<Option<usize>>,
pub specifications: Vec<PreparedAcBusSpecification>,
pub reference_buses: ReferenceBuses,
pub buses: AcPfBusData,
pub generators: AcPfGeneratorData,
pub branches: AcBranchData,
}Expand description
Matrix free AC power flow input on the branch pi model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Stringn_buses: usizen_source_generators: usizen_source_branches: usizebase_mva: f64units: Unitsskip_zero_impedance: boolcorrect_angle_difference_bounds: boolWhether PowerModels’ angle difference correction was applied.
bus_ids: Vec<BusId>Dense bus index to external bus ID.
bus_analysis_rows: Vec<usize>Dense bus index to row in the star-lowered analysis network.
bus_source_rows: Vec<Option<usize>>Dense bus index to source bus row. A synthetic transformer star bus has no source row; a source bus specified as isolated has no dense row.
specifications: Vec<PreparedAcBusSpecification>Bus specifications in dense bus order. A synthetic transformer star
bus is a zero injection PQ junction. Source rows specified as isolated
are absent from the numerical rows but remain on the AcPfInstance.
reference_buses: ReferenceBusesbuses: AcPfBusDatagenerators: AcPfGeneratorDatabranches: AcBranchDataImplementations
Sourceimpl AcPfPreparation
impl AcPfPreparation
pub fn n_generators(&self) -> usize
pub fn n_branches(&self) -> usize