#[non_exhaustive]pub struct LinDist3FlowDeviceData {
pub loads: Vec<LinDist3FlowLoadData>,
pub shunts: Vec<LinDist3FlowShuntData>,
pub generators: Vec<LinDist3FlowGeneratorData>,
pub sources: Vec<LinDist3FlowSourceData>,
pub balances: Vec<LinDist3FlowBalanceRow>,
}Expand description
All device rows and the fully expanded nodal balances.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.loads: Vec<LinDist3FlowLoadData>shunts: Vec<LinDist3FlowShuntData>generators: Vec<LinDist3FlowGeneratorData>sources: Vec<LinDist3FlowSourceData>balances: Vec<LinDist3FlowBalanceRow>Trait Implementations
Sourceimpl Clone for LinDist3FlowDeviceData
impl Clone for LinDist3FlowDeviceData
Sourcefn clone(&self) -> LinDist3FlowDeviceData
fn clone(&self) -> LinDist3FlowDeviceData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinDist3FlowDeviceData
impl Debug for LinDist3FlowDeviceData
Sourceimpl PartialEq for LinDist3FlowDeviceData
impl PartialEq for LinDist3FlowDeviceData
Sourcefn eq(&self, other: &LinDist3FlowDeviceData) -> bool
fn eq(&self, other: &LinDist3FlowDeviceData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LinDist3FlowDeviceData