#[non_exhaustive]pub struct LinDist3FlowStandardForm {
pub p: SparseMatrix,
pub q: Vec<f64>,
pub a: SparseMatrix,
pub b: Vec<f64>,
pub cones: Vec<LinDist3FlowStandardCone>,
pub row_origins: Vec<LinDist3FlowStandardRowOrigin>,
pub scaling: LinDist3FlowScaling,
pub canonical: LinDist3FlowConicProblem,
}Expand description
Clarabel-compatible sparse conic data plus its semantic source model.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.p: SparseMatrixZero quadratic objective matrix, CSC, n x n.
q: Vec<f64>Linear objective vector, length n.
a: SparseMatrixConstraint matrix in CSC storage.
b: Vec<f64>Constraint right-hand side, length m.
cones: Vec<LinDist3FlowStandardCone>Contiguous cone blocks whose dimensions sum to m.
row_origins: Vec<LinDist3FlowStandardRowOrigin>One semantic origin per constraint row.
scaling: LinDist3FlowScalingExact diagonal maps between solver coordinates and canonical SI.
canonical: LinDist3FlowConicProblemCanonical model retained for primal decoding and identity lookup.