#[non_exhaustive]pub struct LinDist3FlowVariableData {
pub variable: LinDist3FlowDecisionVariable,
pub lower: Option<f64>,
pub upper: Option<f64>,
pub objective_coefficient: f64,
}Expand description
One variable column, including its native bound and objective data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.variable: LinDist3FlowDecisionVariablelower: Option<f64>upper: Option<f64>objective_coefficient: f64Trait Implementations
Sourceimpl Clone for LinDist3FlowVariableData
impl Clone for LinDist3FlowVariableData
Sourcefn clone(&self) -> LinDist3FlowVariableData
fn clone(&self) -> LinDist3FlowVariableData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinDist3FlowVariableData
impl Debug for LinDist3FlowVariableData
Sourceimpl PartialEq for LinDist3FlowVariableData
impl PartialEq for LinDist3FlowVariableData
Sourcefn eq(&self, other: &LinDist3FlowVariableData) -> bool
fn eq(&self, other: &LinDist3FlowVariableData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LinDist3FlowVariableData