#[non_exhaustive]pub struct PiecewiseLinearCost {
pub power: Vec<f64>,
pub value: Vec<f64>,
}Expand description
One convex piecewise linear generator cost in preparation units.
power[i] and value[i] are the supplied breakpoint coordinates after
scaling the power coordinate into the preparation’s Units.
Objective values do not scale with the power unit. The preparation builder
validates that both columns have the same length, power is strictly
increasing, and adjacent segment slopes are nondecreasing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.power: Vec<f64>Breakpoint powers in the preparation’s selected power unit.
value: Vec<f64>Objective values at the corresponding breakpoints.