#[non_exhaustive]pub struct ReferenceConstrainedSystem {
pub matrix: SparseMatrix,
pub rhs: Vec<f64>,
pub retained_rows: Vec<usize>,
}Expand description
The reference constrained linear system: the positive definite matrix a sparse solver factors, its right hand side, and the mapping from reduced rows back to bus rows.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.matrix: SparseMatrixThe reference grounded positive semidefinite matrix, n - r square:
the internal positive factor weights, the negation of the public bus
susceptance matrix with the reference rows and columns removed.
rhs: Vec<f64>The right hand side: net injection minus phase shift injection at the retained buses, plus coupling from eliminated reference buses, per unit.
retained_rows: Vec<usize>Reduced row to dense bus row.