#[non_exhaustive]pub struct AcStorageData {Show 19 fields
pub identities: Vec<String>,
pub bus_of_storage: Vec<usize>,
pub source_rows: Vec<usize>,
pub p: Vec<f64>,
pub q: Vec<f64>,
pub energy: Vec<f64>,
pub energy_rating: Vec<f64>,
pub charge_rating: Vec<f64>,
pub discharge_rating: Vec<f64>,
pub charge_efficiency: Vec<f64>,
pub discharge_efficiency: Vec<f64>,
pub s_max: Vec<f64>,
pub qmin: Vec<f64>,
pub qmax: Vec<f64>,
pub r: Vec<f64>,
pub x: Vec<f64>,
pub p_loss: Vec<f64>,
pub q_loss: Vec<f64>,
pub in_service: Vec<bool>,
}Expand description
Storage data in active storage column order.
Power, energy, ratings, reactive limits, and fixed losses use the
preparation’s selected Units. Efficiencies, impedance, and service
status are dimensionless. Out of service storage and storage attached to
an isolated bus are omitted, matching the other prepared element tables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identities: Vec<String>Stable storage identity aligned with every following column.
bus_of_storage: Vec<usize>Storage column to dense bus index.
source_rows: Vec<usize>Storage column to source storage row.
p: Vec<f64>q: Vec<f64>energy: Vec<f64>energy_rating: Vec<f64>charge_rating: Vec<f64>discharge_rating: Vec<f64>charge_efficiency: Vec<f64>discharge_efficiency: Vec<f64>s_max: Vec<f64>qmin: Vec<f64>qmax: Vec<f64>r: Vec<f64>x: Vec<f64>p_loss: Vec<f64>q_loss: Vec<f64>in_service: Vec<bool>Trait Implementations
Sourceimpl Clone for AcStorageData
impl Clone for AcStorageData
Sourcefn clone(&self) -> AcStorageData
fn clone(&self) -> AcStorageData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AcStorageData
impl Debug for AcStorageData
Sourceimpl<'de> Deserialize<'de> for AcStorageData
impl<'de> Deserialize<'de> for AcStorageData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AcStorageData
impl PartialEq for AcStorageData
Sourcefn eq(&self, other: &AcStorageData) -> bool
fn eq(&self, other: &AcStorageData) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AcStorageData
impl Serialize for AcStorageData
impl StructuralPartialEq for AcStorageData